@@ -31,6 +31,11 @@ class AllocateEipAddressRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_IpAddress(self): # String
+		return self.get_query_params().get('IpAddress')
+
+	def set_IpAddress(self, IpAddress):  # String
+		self.add_query_param('IpAddress', IpAddress)
 	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
@@ -61,6 +66,11 @@ class AllocateEipAddressRequest(RpcRequest):
 
 	def set_ResourceGroupId(self, ResourceGroupId):  # String
 		self.add_query_param('ResourceGroupId', ResourceGroupId)
+	def get_Zone(self): # String
+		return self.get_query_params().get('Zone')
+
+	def set_Zone(self, Zone):  # String
+		self.add_query_param('Zone', Zone)
 	def get_Netmode(self): # String
 		return self.get_query_params().get('Netmode')
 
@@ -106,6 +116,11 @@ class AllocateEipAddressRequest(RpcRequest):
 
 	def set_ActivityId(self, ActivityId):  # Long
 		self.add_query_param('ActivityId', ActivityId)
+	def get_InstanceId(self): # String
+		return self.get_query_params().get('InstanceId')
+
+	def set_InstanceId(self, InstanceId):  # String
+		self.add_query_param('InstanceId', InstanceId)
 	def get_InternetChargeType(self): # String
 		return self.get_query_params().get('InternetChargeType')
 
