@@ -31,11 +31,6 @@ class CreateDhcpOptionsSetRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_BootFileName(self): # String
-		return self.get_query_params().get('BootFileName')
-
-	def set_BootFileName(self, BootFileName):  # String
-		self.add_query_param('BootFileName', BootFileName)
 	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
@@ -46,16 +41,30 @@ class CreateDhcpOptionsSetRequest(RpcRequest):
 
 	def set_ClientToken(self, ClientToken):  # String
 		self.add_query_param('ClientToken', ClientToken)
-	def get_TFTPServerName(self): # String
-		return self.get_query_params().get('TFTPServerName')
+	def get_ResourceGroupId(self): # String
+		return self.get_query_params().get('ResourceGroupId')
 
-	def set_TFTPServerName(self, TFTPServerName):  # String
-		self.add_query_param('TFTPServerName', TFTPServerName)
+	def set_ResourceGroupId(self, ResourceGroupId):  # String
+		self.add_query_param('ResourceGroupId', ResourceGroupId)
+	def get_LeaseTime(self): # String
+		return self.get_query_params().get('LeaseTime')
+
+	def set_LeaseTime(self, LeaseTime):  # String
+		self.add_query_param('LeaseTime', LeaseTime)
 	def get_DomainNameServers(self): # String
 		return self.get_query_params().get('DomainNameServers')
 
 	def set_DomainNameServers(self, DomainNameServers):  # String
 		self.add_query_param('DomainNameServers', DomainNameServers)
+	def get_Tags(self): # RepeatList
+		return self.get_query_params().get('Tag')
+
+	def set_Tags(self, Tag):  # RepeatList
+		for depth1 in range(len(Tag)):
+			if Tag[depth1].get('Key') is not None:
+				self.add_query_param('Tag.' + str(depth1 + 1) + '.Key', Tag[depth1].get('Key'))
+			if Tag[depth1].get('Value') is not None:
+				self.add_query_param('Tag.' + str(depth1 + 1) + '.Value', Tag[depth1].get('Value'))
 	def get_DhcpOptionsSetDescription(self): # String
 		return self.get_query_params().get('DhcpOptionsSetDescription')
 
@@ -91,3 +100,8 @@ class CreateDhcpOptionsSetRequest(RpcRequest):
 
 	def set_DhcpOptionsSetName(self, DhcpOptionsSetName):  # String
 		self.add_query_param('DhcpOptionsSetName', DhcpOptionsSetName)
+	def get_Ipv6LeaseTime(self): # String
+		return self.get_query_params().get('Ipv6LeaseTime')
+
+	def set_Ipv6LeaseTime(self, Ipv6LeaseTime):  # String
+		self.add_query_param('Ipv6LeaseTime', Ipv6LeaseTime)
