@@ -76,6 +76,15 @@ class CreateNatGatewayRequest(RpcRequest):
 
 	def set_NatType(self, NatType):  # String
 		self.add_query_param('NatType', NatType)
+	def get_Tags(self): # RepeatList
+		return self.get_query_params().get('Tag')
+
+	def set_Tags(self, Tag):  # RepeatList
+		for depth1 in range(len(Tag)):
+			if Tag[depth1].get('Value') is not None:
+				self.add_query_param('Tag.' + str(depth1 + 1) + '.Value', Tag[depth1].get('Value'))
+			if Tag[depth1].get('Key') is not None:
+				self.add_query_param('Tag.' + str(depth1 + 1) + '.Key', Tag[depth1].get('Key'))
 	def get_InstanceChargeType(self): # String
 		return self.get_query_params().get('InstanceChargeType')
 
@@ -121,6 +130,11 @@ class CreateNatGatewayRequest(RpcRequest):
 
 	def set_Name(self, Name):  # String
 		self.add_query_param('Name', Name)
+	def get_EipBindMode(self): # String
+		return self.get_query_params().get('EipBindMode')
+
+	def set_EipBindMode(self, EipBindMode):  # String
+		self.add_query_param('EipBindMode', EipBindMode)
 	def get_PricingCycle(self): # String
 		return self.get_query_params().get('PricingCycle')
 
