@@ -71,6 +71,11 @@ class CreateVirtualBorderRouterRequest(RpcRequest):
 
 	def set_PeerIpv6GatewayIp(self, PeerIpv6GatewayIp):  # String
 		self.add_query_param('PeerIpv6GatewayIp', PeerIpv6GatewayIp)
+	def get_ResourceGroupId(self): # String
+		return self.get_query_params().get('ResourceGroupId')
+
+	def set_ResourceGroupId(self, ResourceGroupId):  # String
+		self.add_query_param('ResourceGroupId', ResourceGroupId)
 	def get_PeeringSubnetMask(self): # String
 		return self.get_query_params().get('PeeringSubnetMask')
 
@@ -106,6 +111,15 @@ class CreateVirtualBorderRouterRequest(RpcRequest):
 
 	def set_OwnerId(self, OwnerId):  # Long
 		self.add_query_param('OwnerId', OwnerId)
+	def get_Tagss(self): # RepeatList
+		return self.get_query_params().get('Tags')
+
+	def set_Tagss(self, Tags):  # RepeatList
+		for depth1 in range(len(Tags)):
+			if Tags[depth1].get('Value') is not None:
+				self.add_query_param('Tags.' + str(depth1 + 1) + '.Value', Tags[depth1].get('Value'))
+			if Tags[depth1].get('Key') is not None:
+				self.add_query_param('Tags.' + str(depth1 + 1) + '.Key', Tags[depth1].get('Key'))
 	def get_PhysicalConnectionId(self): # String
 		return self.get_query_params().get('PhysicalConnectionId')
 
