@@ -71,6 +71,15 @@ class DescribeNatGatewaysRequest(RpcRequest):
 
 	def set_NatGatewayId(self, NatGatewayId):  # String
 		self.add_query_param('NatGatewayId', NatGatewayId)
+	def get_Tags(self): # RepeatList
+		return self.get_query_params().get('Tag')
+
+	def set_Tags(self, Tag):  # RepeatList
+		for depth1 in range(len(Tag)):
+			if Tag[depth1].get('Value') is not None:
+				self.add_query_param('Tag.' + str(depth1 + 1) + '.Value', Tag[depth1].get('Value'))
+			if Tag[depth1].get('Key') is not None:
+				self.add_query_param('Tag.' + str(depth1 + 1) + '.Key', Tag[depth1].get('Key'))
 	def get_InstanceChargeType(self): # String
 		return self.get_query_params().get('InstanceChargeType')
 
