@@ -36,6 +36,11 @@ class DescribeRegionsRequest(RpcRequest):
 
 	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
 		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_ProductType(self): # String
+		return self.get_query_params().get('ProductType')
+
+	def set_ProductType(self, ProductType):  # String
+		self.add_query_param('ProductType', ProductType)
 	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
