@@ -66,6 +66,11 @@ class DescribeSnatTableEntriesRequest(RpcRequest):
 
 	def set_SnatEntryId(self, SnatEntryId):  # String
 		self.add_query_param('SnatEntryId', SnatEntryId)
+	def get_NatGatewayId(self): # String
+		return self.get_query_params().get('NatGatewayId')
+
+	def set_NatGatewayId(self, NatGatewayId):  # String
+		self.add_query_param('NatGatewayId', NatGatewayId)
 	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
