@@ -41,11 +41,21 @@ class DescribeVirtualBorderRoutersRequest(RpcRequest):
 
 	def set_PageNumber(self, PageNumber):  # Integer
 		self.add_query_param('PageNumber', PageNumber)
+	def get_ResourceGroupId(self): # String
+		return self.get_query_params().get('ResourceGroupId')
+
+	def set_ResourceGroupId(self, ResourceGroupId):  # String
+		self.add_query_param('ResourceGroupId', ResourceGroupId)
 	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
 	def set_PageSize(self, PageSize):  # Integer
 		self.add_query_param('PageSize', PageSize)
+	def get_IncludeCrossAccountVbr(self): # Boolean
+		return self.get_query_params().get('IncludeCrossAccountVbr')
+
+	def set_IncludeCrossAccountVbr(self, IncludeCrossAccountVbr):  # Boolean
+		self.add_query_param('IncludeCrossAccountVbr', IncludeCrossAccountVbr)
 	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
@@ -56,6 +66,15 @@ class DescribeVirtualBorderRoutersRequest(RpcRequest):
 
 	def set_OwnerId(self, OwnerId):  # Long
 		self.add_query_param('OwnerId', OwnerId)
+	def get_Tagss(self): # RepeatList
+		return self.get_query_params().get('Tags')
+
+	def set_Tagss(self, Tags):  # RepeatList
+		for depth1 in range(len(Tags)):
+			if Tags[depth1].get('Value') is not None:
+				self.add_query_param('Tags.' + str(depth1 + 1) + '.Value', Tags[depth1].get('Value'))
+			if Tags[depth1].get('Key') is not None:
+				self.add_query_param('Tags.' + str(depth1 + 1) + '.Key', Tags[depth1].get('Key'))
 	def get_Filters(self): # RepeatList
 		return self.get_query_params().get('Filter')
 
@@ -63,6 +82,6 @@ class DescribeVirtualBorderRoutersRequest(RpcRequest):
 		for depth1 in range(len(Filter)):
 			if Filter[depth1].get('Value') is not None:
 				for depth2 in range(len(Filter[depth1].get('Value'))):
-					self.add_query_param('Filter.' + str(depth1 + 1) + '.Value' + str(depth2 + 1), Filter[depth1].get('Value')[depth2])
+					self.add_query_param('Filter.' + str(depth1 + 1) + '.Value.' + str(depth2 + 1), Filter[depth1].get('Value')[depth2])
 			if Filter[depth1].get('Key') is not None:
 				self.add_query_param('Filter.' + str(depth1 + 1) + '.Key', Filter[depth1].get('Key'))
