@@ -66,6 +66,11 @@ class ModifyBgpGroupAttributeRequest(RpcRequest):
 
 	def set_IsFakeAsn(self, IsFakeAsn):  # Boolean
 		self.add_query_param('IsFakeAsn', IsFakeAsn)
+	def get_ClearAuthKey(self): # Boolean
+		return self.get_query_params().get('ClearAuthKey')
+
+	def set_ClearAuthKey(self, ClearAuthKey):  # Boolean
+		self.add_query_param('ClearAuthKey', ClearAuthKey)
 	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
@@ -76,6 +81,11 @@ class ModifyBgpGroupAttributeRequest(RpcRequest):
 
 	def set_OwnerAccount(self, OwnerAccount):  # String
 		self.add_query_param('OwnerAccount', OwnerAccount)
+	def get_RouteQuota(self): # Integer
+		return self.get_query_params().get('RouteQuota')
+
+	def set_RouteQuota(self, RouteQuota):  # Integer
+		self.add_query_param('RouteQuota', RouteQuota)
 	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
@@ -86,3 +96,8 @@ class ModifyBgpGroupAttributeRequest(RpcRequest):
 
 	def set_Name(self, Name):  # String
 		self.add_query_param('Name', Name)
+	def get_LocalAsn(self): # Long
+		return self.get_query_params().get('LocalAsn')
+
+	def set_LocalAsn(self, LocalAsn):  # Long
+		self.add_query_param('LocalAsn', LocalAsn)
