@@ -71,3 +71,8 @@ class ModifyNatGatewayAttributeRequest(RpcRequest):
 
 	def set_Name(self, Name):  # String
 		self.add_query_param('Name', Name)
+	def get_EipBindMode(self): # String
+		return self.get_query_params().get('EipBindMode')
+
+	def set_EipBindMode(self, EipBindMode):  # String
+		self.add_query_param('EipBindMode', EipBindMode)
