@@ -31,11 +31,6 @@ class UpdateDhcpOptionsSetAttributeRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_BootFileName(self): # String
-		return self.get_query_params().get('BootFileName')
-
-	def set_BootFileName(self, BootFileName):  # String
-		self.add_query_param('BootFileName', BootFileName)
 	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
@@ -46,11 +41,11 @@ class UpdateDhcpOptionsSetAttributeRequest(RpcRequest):
 
 	def set_ClientToken(self, ClientToken):  # String
 		self.add_query_param('ClientToken', ClientToken)
-	def get_TFTPServerName(self): # String
-		return self.get_query_params().get('TFTPServerName')
+	def get_LeaseTime(self): # String
+		return self.get_query_params().get('LeaseTime')
 
-	def set_TFTPServerName(self, TFTPServerName):  # String
-		self.add_query_param('TFTPServerName', TFTPServerName)
+	def set_LeaseTime(self, LeaseTime):  # String
+		self.add_query_param('LeaseTime', LeaseTime)
 	def get_DomainNameServers(self): # String
 		return self.get_query_params().get('DomainNameServers')
 
@@ -96,3 +91,8 @@ class UpdateDhcpOptionsSetAttributeRequest(RpcRequest):
 
 	def set_DhcpOptionsSetName(self, DhcpOptionsSetName):  # String
 		self.add_query_param('DhcpOptionsSetName', DhcpOptionsSetName)
+	def get_Ipv6LeaseTime(self): # String
+		return self.get_query_params().get('Ipv6LeaseTime')
+
+	def set_Ipv6LeaseTime(self, Ipv6LeaseTime):  # String
+		self.add_query_param('Ipv6LeaseTime', Ipv6LeaseTime)
